"""
get_files_list

Python package that provides a utility function to recursively get files that match a pattern.
"""

from .get_dir_content import get_dir_content

__version__ = "0.3.1"
__author__ = "Luca Angioloni"
